require 'spec_helper'

describe Mongoid::Oslc::Strategy do
  let(:parser) { Mongoid::Oslc::Strategy }

  def parse_query(query, verbose = true)
    parser.to_query(query, :verbose => verbose)
  end

  it "has to_query method" do
    parser.respond_to?(:to_query).should be_true
  end

  describe "#parse" do

    it "should parse simple query" do
      parse_query('dcterms:title="requirement"').should eql({title: "requirement"})
    end

    it "should parse not simple query" do
      parse_query('dcterms:title="requirement" and dcterms:description="desc" and dcterms:creator=blank').should eql({title: "requirement", description: 'desc', creators: []})
    end

    it "should parse query with conjunction" do
      parse_query('dcterms:title="requirement" and dcterms:description="first"').should eql({
        title: "requirement", description: "first"
      })
    end

    it "should parse query with other comparison_op" do
      parse_query('dcterms:created>"2010-04-01"').should eql({created_at: {"$gt"=>"2010-04-01"}})
    end

    it "should parse query with range" do
      parse_query('dcterms:created>"2012-12-08" and dcterms:created<"2012-12-30"').should eql({created_at: {"$gt"=>"2012-12-08", "$lt"=>"2012-12-30"}})
    end

    it "should parse query with not value" do
      parse_query('dcterms:title!="First"').should eql({title: {"$ne" => "First"}})
    end

    it "should parse query with blank value" do
      parse_query('dcterms:title=blank').should eql({title: nil})
    end

    it "should parse query with blank value" do
      parse_query('dcterms:creator=blank').should eql({creators: []})
    end

    it "should parse query with decimal value" do
      parse_query('dcterms:title=+5').should eql({title: 5.0})
    end

    it "should parse query with decimal value" do
      parse_query('dcterms:title=-5.151').should eql({title: -5.151})
    end

    it "should parse query with boolean value" do
      parse_query('oslc_cm:closed=true').should eql({closed: true})
    end

    it "should parse query with boolean value" do
      parse_query('oslc_cm:closed=false').should eql({closed: false})
    end

    it "should parse query with one values" do
      parse_query('dcterms:title in ["First"]').should eql({title: {"$in"=>["First"]}})
    end

    it "should parse query with array values" do
      parse_query('dcterms:title in ["First","Second",false,blank,+5]').should eql({title: {"$in"=>["First", "Second", false, nil, 5.0]}})
    end

    it "should parse query with wild char" do
      parse_query('dcterms:title="*requirement*"').should eql({title: /requirement/})
    end

    it "should parse query with wild char" do
      parse_query('dcterms:title="requirement*"').should eql({title: /\Arequirement/})
    end

    describe "custom fields" do
      it "should parse query with custom namespace" do
        parse_query('oslc_custom:color="Black"').should eql({color: "Black"})
      end
    end
  end
end
