require 'rubygems'
require 'bundler/setup'
require 'mongoid'
require 'mongoid/oslc'

require 'rspec'

class MongoDocument
  include Mongoid::Document
  include Mongoid::Oslc
  include Mongoid::Timestamps

  domain    'oslc_cm'
  describe  'http://open-services.net/ns/cm#ChangeRequest'

  oslc_field :title,        type: String, mapping: 'dcterms:title'
  oslc_field :description,  type: String, mapping: 'dcterms:description'
  oslc_field :creators,     type: Array,  mapping: 'dcterms:creator', value_type: 'Resource', default: []
  oslc_field :closed,       type: Boolean,mapping: 'oslc_cm:closed'

  register_oslc_field :created_at, mapping: 'dcterms:created',  value_type: 'DateTime'
  register_oslc_field :updated_at, mapping: 'dcterms:modified', value_type: 'DateTime'

end

Mongoid.configure do |config|
  config.connect_to('mongoid_oslc_where_test')
end

RSpec.configure do |config|
  config.mock_with :rspec
  config.after(:each) { Mongoid.purge! }
end
